@@ -3,7 +3,6 @@
  *
  * Author:  Kazu Yamamoto <Kazu@Mew.org>
  * Created: Oct 17, 2000
- * Revised: Jul 10, 2001
  *
  * Code:
  */
@@ -95,7 +94,7 @@ Ungetc() {
 	if (Ppos > 0)
 		Ppos--;
 	else
-		warn_exit("ungetc is impossible.\n");
+		warn_exit("ungetc is impossible.");
 }
 
 /****************************************************************
@@ -140,7 +139,7 @@ token(char **ret) {
 			break;
 		case '\\':
 			if ((c = Getc()) == EOF)
-				warn_exit("broken escape.\n");
+				warn_exit("broken escape.");
 			/* fall through */
 		default:
 			type = P_STR;
@@ -155,7 +154,7 @@ token(char **ret) {
 			switch (c) {
 			case '\\':
 				if ((c = Getc()) == EOF)
-					warn_exit("broken escape.\n");
+					warn_exit("broken escape.");
 				Keyval[i++] = c;
 				break;
 			case '"':
@@ -165,7 +164,7 @@ token(char **ret) {
 				break;
 			}
 		}
-		warn_exit("broken quoted string.\n");
+		warn_exit("broken quoted string.");
 	}
 
 	while ((c = Getc()) != EOF) {
@@ -212,7 +211,7 @@ token(char **ret) {
 				break;
 			}
 			if ((c = Getc()) == EOF)
-				warn_exit("broken escape.\n");
+				warn_exit("broken escape.");
 			/* fall through */
 		default:
 			if (type != P_STR) {
@@ -272,9 +271,9 @@ exp_eq(struct pat *top) {
 		if (q->typ == P_EQ  || q->typ == P_CEQ ||
 		    q->typ == P_NEQ || q->typ == P_CNE) {
 			if (q->prv == NULL || q->nxt == NULL)
-				warn_exit("broken eq/neq.\n");
+				warn_exit("broken eq/neq.");
 			if (q->prv->typ != P_STR || q->nxt->typ != P_STR)
-				warn_exit("broken eq/neq.\n");
+				warn_exit("broken eq/neq.");
 			n = get_pat();
 			p = q->prv;
 			n->typ = q->typ;
@@ -313,10 +312,10 @@ exp_sq(struct pat *top) {
 			break;
 		case P_RSQ:
 			level--;
-			if (level < 0) warn_exit("too many ')'.\n");
+			if (level < 0) warn_exit("too many ')'.");
 			if (level == 0) {
 				if (p->nxt == q)
-					warn_exit("empty '()'.\n");
+					warn_exit("empty '()'.");
 				n = p->nxt;
 				n->prv = NULL;
 				q->prv->nxt = NULL;
@@ -346,7 +345,7 @@ exp_sq(struct pat *top) {
 	}
 
 	if (level > 0)
-		warn_exit("too many '('.\n");
+		warn_exit("too many '('.");
 	return top;
 }
 
@@ -367,9 +366,9 @@ exp_not(struct pat *top) {
 	while (p != NULL)
 		if (p->typ == P_NOT) {
 			if ((q = p->nxt) == NULL)
-				warn_exit("broken not.\n");
+				warn_exit("broken not.");
 			if (q->typ != P_EXP)
-				warn_exit("broken not.\n");
+				warn_exit("broken not.");
 			n = get_pat();
 			m = get_pat();
 			p->dwn = n;
@@ -421,9 +420,9 @@ exp_lao(struct pat *top, enum ptype lao) {
 			p = q->prv;
 			r = q->nxt;
 			if (p == NULL || r == NULL)
-				warn_exit("broken and/or.\n");
+				warn_exit("broken and/or.");
 			if (p->typ != P_EXP || r->typ != P_EXP)
-				warn_exit("broken and/or.\n");
+				warn_exit("broken and/or.");
 			n = get_pat();
 			n->typ = P_EXP;
 			n->prv = p->prv;
@@ -455,7 +454,7 @@ exp_lao(struct pat *top, enum ptype lao) {
 private struct pat *
 exp_exp(struct pat *top) {
 	if (top == NULL)
-		warn_exit("illegal pattern.\n");
+		warn_exit("invalid pattern.");
 	top = exp_sq(top);
 	top = exp_not(top);
 	top = exp_lao(top, P_AND);
@@ -547,7 +546,7 @@ eval_exp(struct pat *p) {
 		return eval_exp(p->dwn);
 		break;
 	default:
-		warn_exit("broken tree.\n");
+		warn_exit("broken tree.");
 	}
 	return TRUE; /* never reached */
 }
@@ -621,7 +620,7 @@ print_exp(struct pat *p, int level){
 		print_exp(p->dwn, level + 1);
 		break;
 	default:
-		warn_exit("broken tree.\n");
+		warn_exit("broken tree.");
 	}
 }
 
@@ -633,7 +632,7 @@ main(int argc, char *argv[])
 
 	warn_prog = progname;
 	if (argc != 2)
-		warn_exit("argc != 2\n");
+		warn_exit("argc != 2.");
 	top = parse_pattern(argv[1]);
 	print_exp(top, 0);
 	exit(EXIT_SUCCESS);
@@ -641,7 +640,7 @@ main(int argc, char *argv[])
 #endif /* DEBUG */
 
 /* 
- * Copyright (C) 2000-2003 Mew developing team.
+ * Copyright (C) 2000-2005 Mew developing team.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
