@@ -101,6 +101,7 @@
 ;;;
 
 (defmacro mew-decode-narrow-to-header (&rest body)
+  (declare (debug (&rest form)))
   `(progn
      (if (re-search-forward mew-eoh nil t)
 	 (beginning-of-line)
@@ -298,8 +299,9 @@ Return the existence MIME-Version: and the value of Subject:."
 	     ;; MIME-Version:
 	     (setq mimep (string-match
 			  mew-mv:-num
-			  (mew-addrstr-parse-value
-			   (mew-buffer-substring med (point)))))))
+			  (or (mew-addrstr-parse-value
+			       (mew-buffer-substring med (point)))
+			      "")))))
 	   (when prop
 	     (setq key-face (mew-key-face key nspec))
 	     (setq val-face (mew-val-face key nspec))
