@@ -16,14 +16,15 @@
 
 (defvar mew-pgp-ver nil
   "Automatically set 0 if PGP version is 2.
-Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
+Set 1 if 5. Set 2 if 6. Set 3 if GNUPG. Set 4 if GNUPG2.")
 
-(defconst mew-pgp-ver2 0)
-(defconst mew-pgp-ver5 1)
-(defconst mew-pgp-ver6 2)
-(defconst mew-pgp-verg 3)
-(defconst mew-pgp-list '("PGPv2" "PGPv5" "PGPv6" "GNUPG"))
-(defconst mew-pgp-keys '(pgpv2 pgpv5 pgpv6 gnupg)) ;; use symbols, cases are string
+(defconst mew-pgp-ver2  0)
+(defconst mew-pgp-ver5  1)
+(defconst mew-pgp-ver6  2)
+(defconst mew-pgp-verg  3)
+(defconst mew-pgp-verg2 4)
+(defconst mew-pgp-list '("PGPv2" "PGPv5" "PGPv6" "GNUPG" "GNUPG2"))
+(defconst mew-pgp-keys '(pgpv2 pgpv5 pgpv6 gnupg gnupg2)) ;; use symbols, cases are string
 
 ;; mew-prog-pgp is used only for version check
 (defvar mew-prog-pgp2  "pgp") ;; "pgp263i", PGP selection
@@ -32,87 +33,98 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 (defvar mew-prog-pgp5s "pgps")
 (defvar mew-prog-pgp5v "pgpv")
 (defvar mew-prog-pgp5k "pgpk")
-(defvar mew-prog-pgp6  "pgp") ;; "pgp651i", PGP selection
-(defvar mew-prog-gpg   "gpg") ;; PGP selection
+(defvar mew-prog-pgp6  "pgp")  ;; "pgp651i", PGP selection
+(defvar mew-prog-gpg   "gpg")  ;; PGP selection
+(defvar mew-prog-gpg2  "gpg")  ;; PGP selection
 
 (defvar mew-prog-pgpe
-  `(,mew-prog-pgp2 ,mew-prog-pgp5e ,mew-prog-pgp6 ,mew-prog-gpg))
+  `(,mew-prog-pgp2 ,mew-prog-pgp5e ,mew-prog-pgp6 ,mew-prog-gpg ,mew-prog-gpg2))
 (defvar mew-prog-pgps
-  `(,mew-prog-pgp2 ,mew-prog-pgp5s ,mew-prog-pgp6 ,mew-prog-gpg))
+  `(,mew-prog-pgp2 ,mew-prog-pgp5s ,mew-prog-pgp6 ,mew-prog-gpg ,mew-prog-gpg2))
 (defvar mew-prog-pgpv
-  `(,mew-prog-pgp2 ,mew-prog-pgp5v ,mew-prog-pgp6 ,mew-prog-gpg))
+  `(,mew-prog-pgp2 ,mew-prog-pgp5v ,mew-prog-pgp6 ,mew-prog-gpg ,mew-prog-gpg2))
 (defvar mew-prog-pgpd
-  `(,mew-prog-pgp2 ,mew-prog-pgp5v ,mew-prog-pgp6 ,mew-prog-gpg))
+  `(,mew-prog-pgp2 ,mew-prog-pgp5v ,mew-prog-pgp6 ,mew-prog-gpg ,mew-prog-gpg2))
 (defvar mew-prog-pgpk
-  `(,mew-prog-pgp2 ,mew-prog-pgp5k ,mew-prog-pgp6 ,mew-prog-gpg))
+  `(,mew-prog-pgp2 ,mew-prog-pgp5k ,mew-prog-pgp6 ,mew-prog-gpg ,mew-prog-gpg2))
 
 (defconst mew-prog-pgpe-arg
   '(("-ea" "+language=en" "+batchmode=on" "+armorlines=0")
     ("-a" "+language=en" "+batchmode=on" "+armorlines=0")
     ("-ea" "+language=en" "+batchmode=on" "+armorlines=0")
+    ("--encrypt" "--armor" "--batch")
     ("--encrypt" "--armor" "--batch")))
 
 (defconst mew-prog-pgpd-arg
   '(("+language=en" "+batchmode=off")
     ("+language=en" "+batchmode=off")
     ("+language=en" "+batchmode=off")
+    ("--decrypt")
     ("--decrypt")))
 
 (defvar mew-prog-pgps-arg ;; local binding
   '(("-sba" "+language=en" "+batchmode=off")
     ("-ba" "+language=en" "+batchmode=off")
     ("-sba" "+language=en" "+batchmode=off")
-    ("--detach-sign" "--armor" "--status-fd" "1")))
+    ("--detach-sign" "--armor" "--status-fd" "1")
+    ("--detach-sign" "--armor" "--status-fd" "1" "--command-fd" "0" "--no-tty" "--yes")))
 
 (defconst mew-prog-pgpv-arg
   '(("+batchmode=on" "+language=en")
     ("+batchmode=on" "+language=en" "+force=on")
     ("+batchmode=on" "+language=en")
+    ("--verify" "--batch")
     ("--verify" "--batch")))
 
 (defconst mew-prog-old-pgpv-arg
   '(("+batchmode=on" "+language=en")
     ("+batchmode=on" "+language=en" "+force=on")
     ("+batchmode=on" "+language=en")
-    ("--decrypt" "--batch"))) ;; --verify does not extract original data
+    ("--decrypt" "--batch")   ;; --verify does not extract original data
+    ("--decrypt" "--batch")))
 
-(defconst mew-prog-pgp-arg-output  '("-o" "-o" "-o" "--output"))
-(defconst mew-prog-pgp-arg-input   '(nil  "-o" nil  nil))
-(defconst mew-prog-pgp-arg-luserid '("-u" "-u" "-u" "--local-user"))
-(defconst mew-prog-pgp-arg-ruserid '(nil  "-r" nil  "--remote-user"))
+(defconst mew-prog-pgp-arg-output  '("-o" "-o" "-o" "--output" "--output"))
+(defconst mew-prog-pgp-arg-input   '(nil  "-o" nil  nil nil))
+(defconst mew-prog-pgp-arg-luserid '("-u" "-u" "-u" "--local-user" "--local-user"))
+(defconst mew-prog-pgp-arg-ruserid '(nil  "-r" nil  "--remote-user" "--remote-user"))
 
 (defconst mew-prog-pgpk-add-arg
   '(("-ka" "+batchmode=on")
     ("-a" "+batchmode=on")
     ("-ka" "+batchmode=on")
+    ("--import" "--batch")
     ("--import" "--batch")))
 
 (defconst mew-prog-pgpk-ext-arg
-  '(("-kxfa") ("-xa") ("+force" "-kxfa") ("--export" "--armor" "--batch")))
+  '(("-kxfa") ("-xa") ("+force" "-kxfa") ("--export" "--armor" "--batch") ("--export" "--armor" "--batch")))
 
 (defconst mew-pgp-msg-signature
   '("\n\\(.*\\) signature from user \\(.*\\)\\."
     "\n\\(.*\\) signature made"
     "\\([a-zA-Z0-9]*\\) signature from user \\(.*\\)\\."
+    " \\(.*\\) signature from \"\\(.*\\)\""
     " \\(.*\\) signature from \"\\(.*\\)\""))
 
 (defconst mew-pgp-msg-key-id
   '("Key ID \\([a-zA-Z0-9]+\\) not found"
     ": 0x\\([a-zA-Z0-9]+\\)"
     ": 0x\\([a-zA-Z0-9]+\\)"
+    "key ID \\([a-zA-Z0-9]+\\)"
     "key ID \\([a-zA-Z0-9]+\\)"))
 
 (defconst mew-pgp-msg-bad-pass
   '("No passphrase"
     "Cannot unlock private key\\|It can only be decrypted"
     "Bad pass phrase"
+    "bad passphrase"
     "bad passphrase"))
 
 (defconst mew-pgp-msg-enter
-  '("Enter" "Enter" "Enter" "xxx"))
+  '("Enter" "Enter" "Enter" "xxx" "xxx"))
 
 (defconst mew-pgp-msg-overwrite
   '("Overwrite (y/N)\\? "
+    "Overwrite (y/N)\\? "
     "Overwrite (y/N)\\? "
     "Overwrite (y/N)\\? "
     "Overwrite (y/N)\\? "))
@@ -121,60 +133,69 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
   '("Enter pass phrase: "
     "Enter pass phrase: "
     "Enter pass phrase: "
+    "Enter passphrase: "
     "Enter passphrase: "))
 
 (defconst mew-pgp-msg-reenter-pass
   '("Enter pass phrase: "
     "Enter pass phrase: "
     "Enter pass phrase: "
+    "Enter passphrase: "
     "Enter passphrase: "))
 
 (defconst mew-pgp-msg-no-enckey
   '("Key matching"
     "No encryption keys"
     "public key matching"
+    "public key not found"
     "public key not found"))
 
 (defconst mew-pgp-msg-no-validkey
   '("DUMMY"
     "^WARNING:[ -9;-~\n]+belongs? to:"
     "^WARNING:[ -9;-~\n]+belongs? to:"
+    "There is no indication that this key really belongs to the owner"
     "There is no indication that this key really belongs to the owner"))
 
 (defconst mew-pgp-msg-pubkey-expired
   '("xxx"
     "xxx"
     "xxx"
+    "encryption failed: unusable public key"
     "encryption failed: unusable public key"))
 
 (defconst mew-pgp-msg-no-vrfkey
-  '("Key matching" "unknown keyid" "key does not meet" "public key not found"))
+  '("Key matching" "unknown keyid" "key does not meet" "public key not found" "public key not found"))
 
 (defconst mew-pgp-msg-no-keyring
-  '("Keyring file" "Keyring file" "NO MESSAGE" "public key not found"))
+  '("Keyring file" "Keyring file" "NO MESSAGE" "public key not found" "public key not found"))
 
 (defconst mew-pgp-msg-no-seckey-or-secring
   '("You do not have the secret key"
     "Cannot find a private key"
     "Signature error\\|You do not have the secret key"
+    "failed: secret key not available"
     "failed: secret key not available"))
 
 (defconst mew-pgp-msg-unsupported
   '("Unsupported packet format" ;; including algorithms and packets
     "Unsupported packet format\\|None of the signatures were understood"
     "Unsupported packet format" ;; including algorithms and packets
+    "xxx"
     "xxx"))
 
 (defconst mew-pgp-msg-nocross
   '("xxx"
     "xxx"
     "xxx"
+    "is not cross-certified"
     "is not cross-certified"))
 
 (defconst mew-pgp-verify-addr
   '(".* \\(signature from user\\) "
     "\\(   \\)"
     ".* \\(signature from user\\) "
+    "gpg: .* \\(from\\|aka\\) "
     "gpg: .* \\(from\\|aka\\) "))
 
 ;; 2: ASCII armor corrupted
@@ -186,7 +207,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 (defconst mew-pgp-msg-no-export-key
   '("Key not found" "No keys" "Key not found" "nothing exported"))
 
-(defvar mew-pgp-micalg '("pgp-md5" "pgp-sha1" "pgp-sha1" "pgp-sha1"))
+(defvar mew-pgp-micalg '("pgp-md5" "pgp-sha1" "pgp-sha1" "pgp-sha1" "pgp-sha1"))
 
 (defvar mew-pgp-hash-alist
   '(("1"  . "pgp-md5")
@@ -271,12 +292,15 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 	(if (search-forward "Pretty Good Privacy(tm) 2" nil t)
 	    (setq mew-pgp-ver mew-pgp-ver2)
 	  (goto-char (point-min))
-	  (if (search-forward "gpg" nil t)
-	      (setq mew-pgp-ver mew-pgp-verg)
+	  (if (search-forward "Unknown system error" nil t)
+	      (setq mew-pgp-ver mew-pgp-verg2)
 	    (goto-char (point-min))
-	    (if (search-forward "Pretty Good Privacy(tm) Version 6" nil t)
-		(setq mew-pgp-ver mew-pgp-ver6)
-	      (setq mew-pgp-ver nil)))))))
+	    (if (search-forward "gpg" nil t)
+		(setq mew-pgp-ver mew-pgp-verg)
+	      (goto-char (point-min))
+	      (if (search-forward "Pretty Good Privacy(tm) Version 6" nil t)
+		  (setq mew-pgp-ver mew-pgp-ver6)
+		(setq mew-pgp-ver nil))))))))
    (t (setq mew-pgp-ver nil))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -290,7 +314,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
   (setq mew-prog-pgp
 	(completing-read
 	 "PGP name: "
-	 (mapcar 'list (list mew-prog-pgp2 mew-prog-pgp5 mew-prog-gpg))
+	 (mapcar 'list (list mew-prog-pgp2 mew-prog-pgp5 mew-prog-gpg mew-prog-gpg2))
 	 nil t))
   (mew-pgp-setup))
 
@@ -417,6 +441,10 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
     (if (and mew-encrypt-to-myself
 	     (not (member mew-inherit-encode-pgp-signer decrypters)))
 	(setq decrypters (cons mew-inherit-encode-pgp-signer decrypters)))
+    (setq decrypters
+	  (mapcar (lambda (x)
+		    (if (string-match "^[^<].*@" x) (concat "<" x ">") x))
+		  decrypters))
     (if (not roption)
 	(setq args (append (list ooption file3 file1) eoptions decrypters))
       (mapc
@@ -434,7 +462,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 ;;; PGP decrypting
 ;;;
 
-(defun mew-pgp-decrypt (file1 file2)
+(defun mew-pgp-decrypt (_file1 file2)
   ;; file1 is a key file. just ignore.
   ;; file2 is an encrypted file with PGP.
   (message "PGP decrypting...")
@@ -486,7 +514,8 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 
 (defun mew-pgp-get-micalg ()
   (let ((micalg (mew-pgp-get mew-pgp-micalg)) alg)
-    (if (/= mew-pgp-ver mew-pgp-verg)
+    (if (and (/= mew-pgp-ver mew-pgp-verg)
+	     (/= mew-pgp-ver mew-pgp-verg2))
 	micalg
       (with-temp-buffer
 	(insert mew-pgp-string)
@@ -529,7 +558,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 ;;; PGP process functions
 ;;;
 
-(defun mew-pgp-process-sentinel (process event)
+(defun mew-pgp-process-sentinel (_process _event)
   (save-excursion
     (let ((decrypted mew-pgp-result-sec-succ)
 	  (msg ""))
@@ -690,12 +719,12 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
   (interactive)
   (mew-pgp-encode-message 'pgp-encryption))
 
-(defun mew-pgp-sign-encrypt-message (&optional arg)
+(defun mew-pgp-sign-encrypt-message (&optional _arg)
   "Sign then encrypt the entire draft with PGP. Input your passphrase."
   (interactive "P")
   (mew-pgp-encode-message 'pgp-signature-encryption))
 
-(defun mew-pgp-encrypt-sign-message (&optional arg)
+(defun mew-pgp-encrypt-sign-message (&optional _arg)
   "Encrypt then sign the entire draft with PGP. Input your passphrase."
   (interactive "P")
   (mew-pgp-encode-message 'pgp-encryption-signature))
@@ -719,18 +748,21 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
   '(("-sat" "+clearsig=on" "+language=en" "+batchmode=off")
     ("-at" "+clearsig=on" "+language=en" "+batchmode=off")
     ("-sat" "+clearsig=on" "+language=en" "+batchmode=off")
-    ("--clearsign" "--armor" "--textmode")))
+    ("--clearsign" "--armor" "--textmode" "--status-fd" "1")
+    ("--clearsign" "--armor" "--textmode" "--status-fd" "1" "--command-fd" "0" "--no-tty" "--yes")))
 
 (defconst mew-prog-old-pgpse-arg
   '(("-seat" "+language=en" "+batchmode=off")
     ("-eat"  "+language=en" "+batchmode=off")
     ("-seat" "+language=en" "+batchmode=off")
+    ("--sign" "--encrypt" "--armor" "--textmode")
     ("--sign" "--encrypt" "--armor" "--textmode")))
 
 (defconst mew-prog-old-pgpe-arg
   '(("-eat" "+language=en" "+batchmode=on" "+armorlines=0")
     ("-at" "+language=en" "+batchmode=on" "+armorlines=0")
     ("-eat" "+language=en" "+batchmode=on" "+armorlines=0")
+    ("--encrypt" "--armor" "--textmode" "--batch")
     ("--encrypt" "--armor" "--textmode" "--batch")))
 
 (defun mew-old-pgp-encode (type &optional signer)
@@ -852,6 +884,10 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
     (if (and mew-encrypt-to-myself
 	     (not (member mew-inherit-encode-pgp-signer decrypters)))
 	(setq decrypters (cons mew-inherit-encode-pgp-signer decrypters)))
+    (setq decrypters
+	  (mapcar (lambda (x)
+		    (if (string-match "^[^<].*@" x) (concat "<" x ">") x))
+		  decrypters))
     (setq file2 (mew-make-temp-name))
     (setq args (list loption mew-inherit-encode-pgp-signer ooption file2 file1))
     (if (not roption)
@@ -993,6 +1029,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 	   (mew-syntax-get-param
 	    (mew-syntax-get-ct (mew-syntax-get-part syntax)) "charset"))
 	  mew-cs-autoconv))
+     (mew-highlight-body-region (point) (point-max))
      (mew-message-set-end-of)
      (set-window-start win start)
      (set-buffer-modified-p nil))))
@@ -1054,7 +1091,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 
 (defvar mew-pgp-tmp-file nil)
 
-(defun mew-mime-pgp-keys (cache begin end &optional params)
+(defun mew-mime-pgp-keys (_cache _begin _end &optional _params)
   "A function to add PGP keys in Application/PGP-Keys to your
 public keyring."
   (mew-elet
@@ -1070,7 +1107,7 @@ public keyring."
     "To add this key to your pubring, type "
     "'\\<mew-summary-mode-map>\\[mew-summary-execute-external]'.\n")))
 
-(defun mew-mime-pgp-keys-ext (cache begin end &optional params)
+(defun mew-mime-pgp-keys-ext (cache begin end &optional _params)
   "A function to add PGP keys to your public keyring."
   (if (not mew-pgp-ver)
       (message "PGP not found")
@@ -1101,6 +1138,8 @@ public keyring."
 	  ((eq mew-pgp-ver mew-pgp-ver6)
 	   (insert "\"pgp -ke\" and \"pgp -ks\" to change them.\n"))
 	  ((eq mew-pgp-ver mew-pgp-verg)
+	   (insert "\"gpg --edit-key\" to change them.\n"))
+	  ((eq mew-pgp-ver mew-pgp-verg2)
 	   (insert "\"gpg --edit-key\" to change them.\n")))
 	 (insert "If you do not know what TRUST and VALIDITY is,\n"
 		 "you should learn the web of trust system BEFORE\n"
@@ -1178,7 +1217,7 @@ according to a URL in a field specified by 'mew-x-pgp-key-list'."
 		       (append mew-prog-pgpkey-args (list uri)))))
     (set-process-sentinel pro 'mew-pgp-fetch-process-sentinel)))
 
-(defun mew-pgp-fetch-process-sentinel (process event)
+(defun mew-pgp-fetch-process-sentinel (process _event)
   (message "PGP key fetching...done")
   (let ((buf (process-buffer process)))
     (with-current-buffer buf
@@ -1227,7 +1266,7 @@ according to a URL in a field specified by 'mew-x-pgp-key-list'."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2012 Mew developing team.
+;; Copyright (C) 1994-2015 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
